==> hoteldruid-mod-sv_2.1.2-1.tar.gz: sv/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Efternamnet kommer &auml;ndras fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "Il nome verrà cambiato da":  		$messaggio = "F&ouml;rnamnet kommer &auml;ndras fr&aring;n"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "K&ouml;net kommer &auml;ndras fr&aring;n"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "F&ouml;delsedatumet kommer &auml;ndras fr&aring;n"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "La via  verrà cambiata da":  		$messaggio = "Gatunamnet kommer &auml;ndras fr&aring;n"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Gatunumret kommer &auml;ndras fr&aring;n"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Staden kommer &auml;ndras fr&aring;n"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Landet kommer &auml;ndras fr&aring;n"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Postnumret kommer &auml;ndras fr&aring;n"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Faxnumret kommer &auml;ndras fr&aring;n"; break;
case "L' email verrà cambiata da":  		$messaggio = "E-postadressen kommer &auml;ndras fr&aring;n"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Det andra telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Det tredje telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "<b>Kommentaren</b> kommer &auml;ndras fr&aring;n"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "<b>Namnet</b> kommer tas bort"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delsedatumet</b> kommer tas bort"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "<b>Telefonnumret</b> kommer tas bort"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "<b>Gatunamnet</b> kommer tas bort"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "<b>Gatunumret</b> kommer tas bort"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "<b>Staden</b> kommer tas bort"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "<b>Landet</b> kommer tas bort"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "<b>Postnumret</b> kommer tas bort"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "<b>Faxnumret</b> kommer tas bort"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "<b>E-postadressen</b> kommer tas bort"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Det <b>andra telefonnumret</b> kommer tas bort"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Det <b>tredje telefonnumret</b> kommer tas bort"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Il cliente":  				$messaggio = "Kunden"; break;
case "è stato modificato":  			$messaggio = "har &auml;ndrats"; break;
case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica i dati del cliente":  		$messaggio = "&Auml;ndra kunddata"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "cambia in":  				$messaggio = "&auml;ndra till"; break;
case "Nome":  					$messaggio = "F&ouml;rnamn"; break;
case "cancella":  				$messaggio = "ta bort"; break;
case "Sesso":  					$messaggio = "K&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "Telefono":  				$messaggio = "Telefonnummer"; break;
case "Via":  					$messaggio = "Gatunamn"; break;
case "Piazza":  				$messaggio = "Torg"; break;
case "Viale":  					$messaggio = "Aveny"; break;
case "Vicolo":  				$messaggio = "V&auml;g"; break;
case "Numero civico":  				$messaggio = "Gatunummer"; break;
case "Città di residenza":  			$messaggio = "Stad"; break;
case "Nazione di residenza":  			$messaggio = "Land"; break;
case "CAP":  					$messaggio = "Postnummer"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-postadress"; break;
case "2° telefono":  				$messaggio = "Andra telefonnummer"; break;
case "3° telefono":  				$messaggio = "Tredje telefonnummer"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Prenotazioni del cliente":  		$messaggio = "Kunds bokningar"; break;
case "nel":  					$messaggio = ""; break;
case "Cognome_del_cliente":  			$messaggio = "Kund_efternamn"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Slutdatum"; break;
case "Tariffa_completa":  			$messaggio = "Komplett_pris"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "Pagato":  				$messaggio = "Betalad"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Infogad av"; break;
case "Si considererà l'utente":  		$messaggio = "Anv&auml;ndare"; break;
case "come colui che ha inserito il cliente":	$messaggio = "kommer ses som den som infogade kunden"; break;
case "Cliente cancellato":  			$messaggio = "Kund borttagen"; break;
case "Cancella il cliente":  			$messaggio = "Ta bort kund"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Den h&auml;r kunden kan inte tas bort eftersom han/hon fortfarande &auml;r associerad med n&aring;gra bokningar"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <div style=\"display: inline; color: red;\">ta bort</div> kunden"; break;
case "SI":  					$messaggio = "JA"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "Scadenza documento":  			$messaggio = "Dokumentet utg&aring;r"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Regionen kommer &auml;ndras fr&aring;n"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Utg&aring;ngsdatumet kommer &auml;ndras fr&aring;n"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "<b>Regionen</b> kommer tas bort"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "<b>Dokumentet</b> kommer tas bort"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "<b>Utg&aring;ngsdatumet f&ouml;r dokumentet</b> kommer tas bort"; break;
case "Cittadinanza":  				$messaggio = "Nationalitet"; break;
case "Nazione di nascita":  			$messaggio = "F&ouml;delseland"; break;
case "Reg./Prov. di nascita":  			$messaggio = "F&ouml;delseregion"; break;
case "Città di nascita":  			$messaggio = "F&ouml;delsestad"; break;
case "Città di rilascio":  			$messaggio = "Utf&auml;rdandestad"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Utf&auml;rdanderegion"; break;
case "Nazione di rilascio":  			$messaggio = "Utf&auml;rdandenation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Nationaliteten kommer &auml;ndras fr&aring;n"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "F&ouml;delselandet kommer &auml;ndras fr&aring;n"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "F&ouml;delseregionen kommer &auml;ndras fr&aring;n"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "F&ouml;delsestaden kommer &auml;ndras fr&aring;n"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdandestaden f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdanderegionen f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdandelandet f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "<b>Nationaliteten</b> kommer tas bort"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delselandet</b> kommer tas bort"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delseregionen</b> kommer tas bort"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delsestaden</b> kommer tas bort"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdandestaden f&ouml;r dokumentet</b> kommer tas bort"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdanderegionen f&ouml;r dokumentet</b> kommer tas bort"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdandelandet f&ouml;r dokumentet</b> kommer tas bort"; break;
case "Codice fiscale":  			$messaggio = "Skattekod"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Skattekoden kommer &auml;ndras fr&aring;n"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "<b>Skattekoden</b> kommer tas bort"; break;
case "Titolo":  				$messaggio = "Titel"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "Tteln kommer &auml;ndras fr&aring;n"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "<b>Titeln</b> kommer tas bort"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/modifica_cliente.php <==
<?php

switch ($messaggio) {

case "Il cognome verrà cambiato da":  		$messaggio = "Efternamnet kommer &auml;ndras fr&aring;n"; break;
case "a":  					$messaggio = "till"; break;
case "Il nome verrà cambiato da":  		$messaggio = "F&ouml;rnamnet kommer &auml;ndras fr&aring;n"; break;
case "Il sesso verrà cambiato a":  		$messaggio = "K&ouml;net kommer &auml;ndras fr&aring;n"; break;
case "La data di nascita  verrà cambiata da":  	$messaggio = "F&ouml;delsedatumet kommer &auml;ndras fr&aring;n"; break;
case "Il telefono verrà cambiato da":  		$messaggio = "Telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "La via  verrà cambiata da":  		$messaggio = "Gatunamnet kommer &auml;ndras fr&aring;n"; break;
case "Il numero civico verrà cambiato da":  	$messaggio = "Gatunumret kommer &auml;ndras fr&aring;n"; break;
case "La città di residenza verrà cambiata da":	$messaggio = "Staden kommer &auml;ndras fr&aring;n"; break;
case "La nazione di residenza verrà cambiata da":	$messaggio = "Landet kommer &auml;ndras fr&aring;n"; break;
case "Il CAP verrà cambiato da":  		$messaggio = "Postnumret kommer &auml;ndras fr&aring;n"; break;
case "Il fax verrà cambiato da":  		$messaggio = "Faxnumret kommer &auml;ndras fr&aring;n"; break;
case "L' email verrà cambiata da":  		$messaggio = "E-postadressen kommer &auml;ndras fr&aring;n"; break;
case "Il 2° telefono verrà cambiato da":  	$messaggio = "Det andra telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "Il 3° telefono verrà cambiato da":  	$messaggio = "Det tredje telefonnumret kommer &auml;ndras fr&aring;n"; break;
case "Il <b>commento</b> verrà cambiato":  	$messaggio = "<b>Kommentaren</b> kommer &auml;ndras fr&aring;n"; break;
case "Il <b>nome</b> verrà cancellato":  	$messaggio = "<b>Namnet</b> kommer tas bort"; break;
case "La <b>data di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delsedatumet</b> kommer tas bort"; break;
case "Il <b>telefono</b> verrà cancellato":  	$messaggio = "<b>Telefonnumret</b> kommer tas bort"; break;
case "La <b>via</b> verrà cancellata":  	$messaggio = "<b>Gatunamnet</b> kommer tas bort"; break;
case "Il <b>n° civico</b> verrà cancellato":  	$messaggio = "<b>Gatunumret</b> kommer tas bort"; break;
case "La <b>città di residenza</b> verrà cancellata":	$messaggio = "<b>Staden</b> kommer tas bort"; break;
case "La <b>nazione di residenza</b> verrà cancellata":	$messaggio = "<b>Landet</b> kommer tas bort"; break;
case "Il <b>CAP</b> verrà cancellato":  	$messaggio = "<b>Postnumret</b> kommer tas bort"; break;
case "Il <b>fax</b> verrà cancellato":  	$messaggio = "<b>Faxnumret</b> kommer tas bort"; break;
case "L' <b>email</b> verrà cancellata":  	$messaggio = "<b>E-postadressen</b> kommer tas bort"; break;
case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "Det <b>andra telefonnumret</b> kommer tas bort"; break;
case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "Det <b>tredje telefonnumret</b> kommer tas bort"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "Il cliente":  				$messaggio = "Kunden"; break;
case "è stato modificato":  			$messaggio = "har &auml;ndrats"; break;
case "Torna indietro":  			$messaggio = "Bak&aring;t"; break;
case "Modifica i dati del cliente":  		$messaggio = "&Auml;ndra kunddata"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "cambia in":  				$messaggio = "&auml;ndra till"; break;
case "Nome":  					$messaggio = "F&ouml;rnamn"; break;
case "cancella":  				$messaggio = "ta bort"; break;
case "Sesso":  					$messaggio = "K&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "Telefono":  				$messaggio = "Telefonnummer"; break;
case "Via":  					$messaggio = "Gatunamn"; break;
case "Piazza":  				$messaggio = "Torg"; break;
case "Viale":  					$messaggio = "Aveny"; break;
case "Vicolo":  				$messaggio = "V&auml;g"; break;
case "Numero civico":  				$messaggio = "Gatunummer"; break;
case "Città di residenza":  			$messaggio = "Stad"; break;
case "Nazione di residenza":  			$messaggio = "Land"; break;
case "CAP":  					$messaggio = "Postnummer"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Email":  					$messaggio = "E-postadress"; break;
case "2° telefono":  				$messaggio = "Andra telefonnummer"; break;
case "3° telefono":  				$messaggio = "Tredje telefonnummer"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Prenotazioni del cliente":  		$messaggio = "Kunds bokningar"; break;
case "nel":  					$messaggio = ""; break;
case "Cognome_del_cliente":  			$messaggio = "Kund_efternamn"; break;
case "Data_iniziale":  				$messaggio = "Startdatum"; break;
case "Data_finale":  				$messaggio = "Slutdatum"; break;
case "Tariffa_completa":  			$messaggio = "Komplett_pris"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "Pagato":  				$messaggio = "Betalad"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "TOTALE":  				$messaggio = "TOTALT"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Inserito da":  				$messaggio = "Infogad av"; break;
case "Si considererà l'utente":  		$messaggio = "Anv&auml;ndare"; break;
case "come colui che ha inserito il cliente":	$messaggio = "kommer ses som den som infogade kunden"; break;
case "Cliente cancellato":  			$messaggio = "Kund borttagen"; break;
case "Cancella il cliente":  			$messaggio = "Ta bort kund"; break;
case "Questo cliente non si può cancellare perchè ancora associato a delle prenotazioni":	$messaggio = "Den h&auml;r kunden kan inte tas bort eftersom han/hon fortfarande &auml;r associerad med n&aring;gra bokningar"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Si è sicuri di voler <div style=\"display: inline; color: red;\">cancellare</div> il cliente":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <div style=\"display: inline; color: red;\">ta bort</div> kunden"; break;
case "SI":  					$messaggio = "JA"; break;
case "Reg./Prov. di residenza":  		$messaggio = "Region"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "Scadenza documento":  			$messaggio = "Dokumentet utg&aring;r"; break;
case "La regione di residenza verrà cambiata da":	$messaggio = "Regionen kommer &auml;ndras fr&aring;n"; break;
case "Il documento verrà cambiato da":  	$messaggio = "Dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La data di scadenza del documento  verrà cambiata da":	$messaggio = "Utg&aring;ngsdatumet kommer &auml;ndras fr&aring;n"; break;
case "La <b>regione di residenza</b> verrà cancellata":	$messaggio = "<b>Regionen</b> kommer tas bort"; break;
case "Il <b>documento</b> verrà cancellato":  	$messaggio = "<b>Dokumentet</b> kommer tas bort"; break;
case "La <b>data di scadenza del documento</b> verrà cancellata":	$messaggio = "<b>Utg&aring;ngsdatumet f&ouml;r dokumentet</b> kommer tas bort"; break;
case "Cittadinanza":  				$messaggio = "Nationalitet"; break;
case "Nazione di nascita":  			$messaggio = "F&ouml;delseland"; break;
case "Reg./Prov. di nascita":  			$messaggio = "F&ouml;delseregion"; break;
case "Città di nascita":  			$messaggio = "F&ouml;delsestad"; break;
case "Città di rilascio":  			$messaggio = "Utf&auml;rdandestad"; break;
case "Reg./Prov. di rilascio":  		$messaggio = "Utf&auml;rdanderegion"; break;
case "Nazione di rilascio":  			$messaggio = "Utf&auml;rdandenation"; break;
case "La cittadinanza verrà cambiata da":  	$messaggio = "Nationaliteten kommer &auml;ndras fr&aring;n"; break;
case "La nazione di nascita verrà cambiata da":	$messaggio = "F&ouml;delselandet kommer &auml;ndras fr&aring;n"; break;
case "La regione di nascita verrà cambiata da":	$messaggio = "F&ouml;delseregionen kommer &auml;ndras fr&aring;n"; break;
case "La città di nascita verrà cambiata da":	$messaggio = "F&ouml;delsestaden kommer &auml;ndras fr&aring;n"; break;
case "La città di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdandestaden f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La regione/provincia di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdanderegionen f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La nazione di rilascio del documento verrà cambiata da":	$messaggio = "Utf&auml;rdandelandet f&ouml;r dokumentet kommer &auml;ndras fr&aring;n"; break;
case "La <b>cittadinanza</b> verrà cancellata":	$messaggio = "<b>Nationaliteten</b> kommer tas bort"; break;
case "La <b>nazione di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delselandet</b> kommer tas bort"; break;
case "La <b>regione di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delseregionen</b> kommer tas bort"; break;
case "La <b>città di nascita</b> verrà cancellata":	$messaggio = "<b>F&ouml;delsestaden</b> kommer tas bort"; break;
case "La <b>città di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdandestaden f&ouml;r dokumentet</b> kommer tas bort"; break;
case "La <b>regione/provincia di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdanderegionen f&ouml;r dokumentet</b> kommer tas bort"; break;
case "La <b>nazione di rilascio del documento</b> verrà cancellata":	$messaggio = "<b>Utf&auml;rdandelandet f&ouml;r dokumentet</b> kommer tas bort"; break;
case "Codice fiscale":  			$messaggio = "Skattekod"; break;
case "Il codice fiscale verrà cambiato da":	$messaggio = "Skattekoden kommer &auml;ndras fr&aring;n"; break;
case "Il <b>codice fiscale</b> verrà cancellato":	$messaggio = "<b>Skattekoden</b> kommer tas bort"; break;
case "Titolo":  				$messaggio = "Titel"; break;
case "Il titolo verrà cambiato da":  		$messaggio = "Tteln kommer &auml;ndras fr&aring;n"; break;
case "Il <b>titolo</b> verrà cancellato":  	$messaggio = "<b>Titeln</b> kommer tas bort"; break;
case "CVC":  					$messaggio = "CVC"; break;
case "Piazzale":  				$messaggio = "Boulevard"; break;
case "documento di tipo":  			$messaggio = "document type"; break;
case "visualizza":  				$messaggio = "view"; break;
case "visualizza il documento":  		$messaggio = "view document"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "La partita iva verrà cambiata da":  	$messaggio = "The VAT number will be changed from"; break;
case "La <b>partita iva</b> verrà cancellata": 	$messaggio = "The <b>VAT number</b> will be deleted"; break;
case "data inserimento":  			$messaggio = "insertion date"; break;
case "carte di credito":  			$messaggio = "credit cards"; break;
case "password per la visualizzazione delle carte di credito":	$messaggio = "password to view credit cards"; break;
case "invia":  					$messaggio = "send"; break;
case "password errata":  			$messaggio = "wrong password"; break;
case "i dati della carta di credito sono stati cancellati":	$messaggio = "credit card data have been deleted"; break;
case "il numero di carta di credito è <span class=\"colred\">sbagliato</span>":	$messaggio = "credit card number is <span class=\"colred\">wrong</span>"; break;
case "il numero CVC è <span class=\"colred\">sbagliato</span>":	$messaggio = "CVC number is <span class=\"colred\">wrong</span>"; break;
case "i dati della carta di credito sono stati inseriti":	$messaggio = "credit card data have been inserted"; break;
case "carta di credito del cliente":  		$messaggio = "credit card of client"; break;
case "Tipo":  					$messaggio = "Type"; break;
case "Numero":  				$messaggio = "Number"; break;
case "Titolare":  				$messaggio = "Holder"; break;
case "Scadenza":  				$messaggio = "Expiration"; break;
case "modifica i dati della carta di credito":	$messaggio = "modify credit card data"; break;
case "cancella questa carta di credito":  	$messaggio = "delete this credit card"; break;
case "soprannome":  				$messaggio = "nickname"; break;
case "Il soprannome verrà cambiato da":  	$messaggio = "The nickname will be changed from"; break;
case "Il <b>soprannome</b> verrà cancellato":  	$messaggio = "The <b>nickname</b> will be deleted"; break;
case "Lingua":  				$messaggio = "Language"; break;
case "La lingua verrà cambiata da":  		$messaggio = "The language will be changed from"; break;
case "La <b>lingua</b> verrà cancellata":  	$messaggio = "The <b>language</b> will be deleted"; break;
case "I dati della carta di credito possono essere visti solo su una connessione sicura":	$messaggio = "Credit card data can be viewed only on a secure connection"; break;
case "Il campo":  				$messaggio = "The field"; break;
case "verrà tolto":  				$messaggio = "will be deleted"; break;
case "verrà modificato":  			$messaggio = "will be modified"; break;
case "verrà aggiunto":  			$messaggio = "will be added"; break;
case "scaduta":  				$messaggio = "expired"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo aver cambiato la password":	$messaggio = "You'll be able to view credit cards again after changing the password"; break;
case "Le carte di credito saranno visualizzabili di nuovo dopo che l'utente amministratore avrà cambiato la password":	$messaggio = "You'll be able to view credit cards again after the administrator user changes the password"; break;
case "Login temporaneamente bloccato":  	$messaggio = "Login temporarily locked"; break;
case "NOTA":  					$messaggio = "NOTICE"; break;
case "questo valore è gia stato cancellato, questa è l'ultima volta che viene visualizzato":	$messaggio = "this value has already been deleted, this is the last time you'll see it"; break;
case "Questo valore verrà visualizzato solo un'altra volta":	$messaggio = "You'll be able to see this value only one more time"; break;
case "Cancellalo ora":  			$messaggio = "Delete it now"; break;
case "CVC cancellato":  			$messaggio = "CVC deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
